@@ -152,6 +152,20 @@ typedef __float128 float128;
 #  define Newxz(v,n,t) Newz(0,v,n,t)
 #endif
 
+/* A perl bug in perl-5.20 onwards can break &PL_sv_yes and  *
+ * &PL_sv_no. In the overload subs we therefore instead      *
+ * use  SvTRUE_nomg_NN where possible, which is available    *
+ * beginning with perl-5.18.0.                               *
+ * Otherwise we continue using &PL_sv_yes as original        *
+ * (&PL_sv_no is not used by this module.)                   *
+ * See See https://github.com/sisyphus/math-decimal64/pull/1 */
+
+#if defined SvTRUE_nomg_NN
+#define SWITCH_ARGS SvTRUE_nomg_NN(third)
+#else
+#define SWITCH_ARGS third==&PL_sv_yes
+#endif
+
 #if MPC_VERSION_MAJOR > 0 || MPC_VERSION_MINOR > 8
 #define SIN_COS_AVAILABLE 1
 #endif
